@@ -1,3 +1,4 @@
+from hashlib import md5
 from .gql_handler_async import *
 from datetime import datetime
 
@@ -78,7 +79,7 @@ class PyXploraApi:
         raise Exception("Fail")
 
     def version(self) -> str:
-        return "1.0.53"
+        return "1.0.56"
 
 ##### Contact Info #####
     async def getContacts_async(self):
@@ -164,8 +165,9 @@ class PyXploraApi:
                         return self.alarms
                     for alarm in alarms_raw['alarms']:
                         self.alarms.append({
+                            'id': md5(f"{alarm['name']}{alarm['occurMin']}{alarm['weekRepeat']}".encode('utf-8')).hexdigest(),
                             'name': alarm['name'],
-                            'start': alarm['start'],
+                            'start': self.__helperTime(alarm['occurMin']),
                             'weekRepeat': alarm['weekRepeat'],
                             'status': alarm['status'],
                         })
@@ -434,6 +436,64 @@ class PyXploraApi:
         for silentTime in (await self.schoolSilentMode_async()):
             res.append(await self.setDisableSilentTime_async(silentTime['id']))
         return res
+
+    async def setEnableAlarmTime_async(self, alarmId) -> bool:
+        retryCounter = 0
+        dataOk = False
+        _raw = None
+        while (not dataOk and (retryCounter < self.maxRetries + 2)):
+            retryCounter +=1
+            self.init()
+            try:
+                await self.askWatchLocate_async()
+                time.sleep(2)
+                enable_raw = await self.__gqlHandler.setEnableAlarmTime_a(alarmId)
+                if 'modifyAlarm' in enable_raw:
+                    _raw = enable_raw['modifyAlarm']
+            except Exception as error:
+                print(error)
+            dataOk = _raw
+            if (not dataOk):
+                self.__logoff()
+                time.sleep(self.retryDelay)
+        if (dataOk):
+            return bool(_raw)
+        else:
+            raise Exception('Xplora API call finally failed with response: ')
+    async def setDisableAlarmTime_async(self, alarmId) -> bool:
+        retryCounter = 0
+        dataOk = False
+        _raw = None
+        while (not dataOk and (retryCounter < self.maxRetries + 2)):
+            retryCounter +=1
+            self.init()
+            try:
+                await self.askWatchLocate_async()
+                time.sleep(2)
+                disable_raw = await self.__gqlHandler.setEnableAlarmTime_a(alarmId, NormalStatus.DISABLE.value)
+                if 'modifyAlarm' in disable_raw:
+                    _raw = disable_raw['modifyAlarm']
+            except Exception as error:
+                print(error)
+            dataOk = _raw
+            if (not dataOk):
+                self.__logoff()
+                time.sleep(self.retryDelay)
+        if (dataOk):
+            return bool(_raw)
+        else:
+            raise Exception('Xplora API call finally failed with response: ')
+    async def setAllEnableAlarmTime_async(self) -> list:
+        res = []
+        for alarmTime in (await self.getWatchAlarm_async()):
+            res.append(await self.setEnableAlarmTime_async(alarmTime['id']))
+        return res
+    async def setAllDisableAlarmTime_async(self) -> list:
+        res = []
+        for alarmTime in (await self.getWatchAlarm_async()):
+            res.append(await self.setDisableAlarmTime_async(alarmTime['id']))
+        return res
+
     async def sendText(self, text): # sender is login User
         return await self.__gqlHandler.sendText_a(await self.getWatchUserID_async(), text)
     async def isAdmin(self):
